@@ -3,7 +3,7 @@ from __future__ import annotations
 
 import os
 import sys
-from distutils.spawn import find_executable
+from shutil import which
 from typing import Any, List, Optional, Union, TextIO
 from typing_extensions import Literal
 
@@ -77,7 +77,7 @@ def connect(command : Optional[str]=None,
     if c is None:
         command = os.getenv('CRYPTOL_SERVER')
         if command is not None:
-            command = find_executable(command)
+            command = which(command)
             if command is not None:
                 c = CryptolConnection(command+" socket", cryptol_path=cryptol_path, log_dest=log_dest, timeout=timeout)
     # Check `CRYPTOL_SERVER_URL` env var if no connection identified yet
@@ -87,7 +87,7 @@ def connect(command : Optional[str]=None,
             c = CryptolConnection(ServerConnection(HttpProcess(url,verify=verify)), cryptol_path, log_dest=log_dest, timeout=timeout)
     # Check if `cryptol-remote-api` is in the PATH if no connection identified yet
     if c is None:
-        command = find_executable('cryptol-remote-api')
+        command = which('cryptol-remote-api')
         if command is not None:
             c = CryptolConnection(command+" socket", cryptol_path=cryptol_path, log_dest=log_dest, timeout=timeout)
     # Raise an error if still no connection identified yet
@@ -203,6 +203,15 @@ class CryptolConnection:
         timeout = timeout if timeout is not None else self.timeout
         self.most_recent_result = CryptolLoadFile(self, filename, timeout)
         return self.most_recent_result
+    
+    def check_docstrings(self, timeout: Optional[float] = None) -> argo.Command:
+        """Check docstrings
+        
+        :param timeout: Optional timeout for this request (in seconds).
+        """
+        timeout = timeout if timeout is not None else self.timeout
+        self.most_recent_result = CryptolCheckDocstrings(self, timeout)
+        return self.most_recent_result
 
     def load_module(self, module_name : str, *, timeout:Optional[float] = None) -> argo.Command:
         """Load a Cryptol module, like ``:module`` at the Cryptol REPL.
@@ -213,6 +222,15 @@ class CryptolConnection:
         self.most_recent_result = CryptolLoadModule(self, module_name, timeout)
         return self.most_recent_result
 
+    def file_deps(self, name : str, isFile : bool, *, timeout:Optional[float] = None) -> argo.Command:
+        """Get information about a module or a file.
+
+        :param timeout: Optional timeout for this request (in seconds).
+        """
+        timeout = timeout if timeout is not None else self.timeout
+        self.most_recent_result = CryptolFileDeps(self, name, isFile, timeout)
+        return self.most_recent_result
+
     def eval_raw(self, expression : Any, *, timeout:Optional[float] = None) -> argo.Command:
         """Like the member method ``eval``, but does not call
         ``from_cryptol_arg`` on the ``.result()``.
@@ -379,13 +397,31 @@ class CryptolConnection:
         return self.most_recent_result
 
     def names(self, *, timeout:Optional[float] = None) -> argo.Command:
-        """Discover the list of names currently in scope in the current context.
+        """Discover the list of term names currently in scope in the current context.
 
         :param timeout: Optional timeout for this request (in seconds)."""
         timeout = timeout if timeout is not None else self.timeout
         self.most_recent_result = CryptolNames(self, timeout)
         return self.most_recent_result
 
+    def parameter_names(self, *, timeout:Optional[float] = None) -> argo.Command:
+        """Discover the list of module parameter names currently in scope in the current context.
+        The result is a subset of the list returned by `names`.
+
+        :param timeout: Optional timeout for this request (in seconds)."""
+        timeout = timeout if timeout is not None else self.timeout
+        self.most_recent_result = CryptolParameterNames(self, timeout)
+        return self.most_recent_result
+
+    def property_names(self, *, timeout:Optional[float] = None) -> argo.Command:
+        """Discover the list of property names currently in scope in the current context.
+        The result is a subset of the list returned by `names`.
+
+        :param timeout: Optional timeout for this request (in seconds)."""
+        timeout = timeout if timeout is not None else self.timeout
+        self.most_recent_result = CryptolPropertyNames(self, timeout)
+        return self.most_recent_result
+
     def focused_module(self, *, timeout:Optional[float] = None) -> argo.Command:
         """Return the name of the currently-focused module.
 
@@ -394,6 +430,14 @@ class CryptolConnection:
         self.most_recent_result = CryptolFocusedModule(self, timeout)
         return self.most_recent_result
 
+    def version(self, *, timeout:Optional[float] = None) -> argo.Command:
+        """Returns version information about the Cryptol server.
+
+        :param timeout: Optional timeout for this request (in seconds)."""
+        timeout = timeout if timeout is not None else self.timeout
+        self.most_recent_result = CryptolVersion(self, timeout)
+        return self.most_recent_result
+
     def reset(self) -> None:
         """Resets the connection, causing its unique state on the server to be freed (if applicable).
 
