@@ -52,6 +52,7 @@ class OfflineSolver(Solver):
 # Cryptol-supported SMT configurations/solvers
 # (see Cryptol.Symbolic.SBV Haskell module)
 CVC4: OnlineSolver          = OnlineSolver("cvc4")
+CVC5: OnlineSolver          = OnlineSolver("cvc5")
 YICES: OnlineSolver         = OnlineSolver("yices")
 Z3: OnlineSolver            = OnlineSolver("z3")
 BOOLECTOR: OnlineSolver     = OnlineSolver("boolector")
@@ -60,6 +61,7 @@ ABC: OnlineSolver           = OnlineSolver("abc")
 OFFLINE: OfflineSolver      = OfflineSolver("offline")
 ANY: OnlineSolver           = OnlineSolver("any")
 SBV_CVC4: OnlineSolver      = OnlineSolver("sbv-cvc4")
+SBV_CVC5: OnlineSolver      = OnlineSolver("sbv-cvc5")
 SBV_YICES: OnlineSolver     = OnlineSolver("sbv-yices")
 SBV_Z3: OnlineSolver        = OnlineSolver("sbv-z3")
 SBV_BOOLECTOR: OnlineSolver = OnlineSolver("sbv-boolector")
@@ -68,6 +70,7 @@ SBV_ABC: OnlineSolver       = OnlineSolver("sbv-abc")
 SBV_OFFLINE: OfflineSolver  = OfflineSolver("sbv-offline")
 SBV_ANY: OnlineSolver       = OnlineSolver("sbv-any")
 W4_CVC4: OnlineSolver       = OnlineSolver("w4-cvc4")
+W4_CVC5: OnlineSolver       = OnlineSolver("w4-cvc5")
 W4_YICES: OnlineSolver      = OnlineSolver("w4-yices")
 W4_Z3: OnlineSolver         = OnlineSolver("w4-z3")
 W4_BOOLECTOR: OnlineSolver  = OnlineSolver("w4-boolector")
